==> mobcommonlib-1.0.1.tar.gz: android/src/main/java/com/mob/plugin/flutter/mobcommonlib/MobcommonlibPlugin.java <==
package com.mob.plugin.flutter.mobcommonlib;

import com.mob.MobSDK;

import androidx.annotation.NonNull;

/* embedding v2（flutter sdk >= 1.20.0）：PART-1 */
//import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** MobcommonlibPlugin */
/* embedding v2（flutter sdk >= 1.20.0）：PART-2 */
//public class MobcommonlibPlugin implements FlutterPlugin, MethodCallHandler {
public class MobcommonlibPlugin implements MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
	public static final String CHANNEL = "mobcommonlib";
  private MethodChannel channel;

	/** Plugin registration. */
	/* embedding v1方式 */
	public static void registerWith(Registrar registrar) {
		MobCommonLog.d("registerWith() called");
		final MethodChannel channel = new MethodChannel(registrar.messenger(), CHANNEL);
		channel.setMethodCallHandler(new MobcommonlibPlugin());
	}

	/* embedding v2（flutter sdk >= 1.20.0）：PART-3 */
//  @Override
//  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
//    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "mobcommonlib");
//    channel.setMethodCallHandler(this);
//  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    } else if (call.method.equals("submitPolicyGrantResult")) {
		boolean granted = call.argument("granted");
		MobCommonLog.d("granted: " + granted);
		MobSDK.submitPolicyGrantResult(granted, null);
	} else {
      result.notImplemented();
    }
  }

	/* embedding v2（flutter sdk >= 1.20.0）：PART-4 */
//  @Override
//  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
//    channel.setMethodCallHandler(null);
//  }
}

==> mobcommonlib-1.0.2.tar.gz: android/src/main/java/com/mob/plugin/flutter/mobcommonlib/MobcommonlibPlugin.java <==
package com.mob.plugin.flutter.mobcommonlib;

import com.mob.MobSDK;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** MobcommonlibPlugin */
public class MobcommonlibPlugin implements FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "mobcommonlib");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    } else if (call.method.equals("submitPolicyGrantResult")) {
		boolean granted = call.argument("granted");
		MobCommonLog.d("granted: " + granted);
		MobSDK.submitPolicyGrantResult(granted, null);
	} else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }
}
